==> xwidgetsbase-10.2.7.tar.gz: lib/XfXWidgets/XfxElencoItem.dart <==
part of xwidgetbase;

class XfxElencoItem extends StatefulWidget {
  XfxElencoItem({
    Key? key,
    this.childMain,
    this.childDetails,
    this.showingDetails = false,
    this.showMainWithDetails = true,
    this.decorationBackGroundContainer,
    this.changeStatoWithTap = true,
    this.onTapItem,
    this.onLongTapItem,
    this.onDoubleTapItem,
    this.margin,
    this.crossAxisAlignment,
    this.backGroundColor_ChildMain,
    this.backGroundColor_ChildDetails,
    this.colorIcon_Collapsed,
    this.colorIcon_Expanded,
    this.colorText_Collapsed,
    this.colorText_Expanded,
    this.showTrailingArrow = true,
    this.icon_Active,
    this.icon_Disabled,
    this.height_Icon,
    this.size_Icon,
    this.width_Icon,
  }) : super(key: key);

  /// default TRUE
  bool showMainWithDetails;
  Widget? childMain;
  bool showingDetails;
  Widget? childDetails;
  bool changeStatoWithTap;
  bool? showTrailingArrow;
  Color? backGroundColor_ChildMain;
  Color? backGroundColor_ChildDetails;
  Color? colorIcon_Expanded;
  Color? colorIcon_Collapsed;
  Color? colorText_Expanded;
  Color? colorText_Collapsed;
  double? width_Icon;
  double? height_Icon;
  double? size_Icon;
  Decoration? decorationBackGroundContainer;
  EdgeInsetsGeometry? margin;
  CrossAxisAlignment? crossAxisAlignment;
  IconData? icon_Active;
  IconData? icon_Disabled;
  Function()? onTapItem;
  Function()? onLongTapItem;
  Function()? onDoubleTapItem;
  @override
  _XfxElencoItemState createState() => _XfxElencoItemState();
}

class _XfxElencoItemState extends State<XfxElencoItem> {
  Widget xBuilder_childMain() {
    return widget.childMain ?? Container();
  }

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
        onTap: widget.changeStatoWithTap
            ? widget.onTapItem ??
                () {
                  if (widget.changeStatoWithTap == true) {
                    setState(() => widget.showingDetails = !widget.showingDetails);
                  }
                }
            : null,
        onLongPress: widget.onLongTapItem ?? () {},
        onDoubleTap: widget.onDoubleTapItem ?? () {},
        child: Container(
            decoration: widget.decorationBackGroundContainer ?? BoxDecoration(),
            margin: widget.margin ?? EdgeInsets.only(bottom: 2),
            child: Column(crossAxisAlignment: widget.crossAxisAlignment ?? CrossAxisAlignment.center, children: [
              (widget.showMainWithDetails == false && widget.showingDetails == true)
                  ? Container()
                  : Container(
                      padding: EdgeInsets.all(5),
                      color: widget.backGroundColor_ChildMain,
                      child: Row(crossAxisAlignment: CrossAxisAlignment.center, children: [
                        Expanded(child: xBuilder_childMain()),
                        (widget.changeStatoWithTap == true && widget.showTrailingArrow == true)
                            ? Container(
                                margin: EdgeInsets.only(top: 10),
                                width: widget.width_Icon ?? 40,
                                height: widget.height_Icon ?? 40,
                                child: Icon(
                                  widget.showingDetails ? widget.icon_Active ?? Icons.keyboard_arrow_up_outlined : widget.icon_Disabled ?? widget.icon_Active ?? Icons.keyboard_arrow_down_outlined,
                                  color: (widget.showingDetails == false) ? widget.colorIcon_Collapsed ?? Colors.grey : widget.colorIcon_Expanded ?? Colors.yellow,
                                  size: widget.size_Icon ?? 28,
                                ))
                            : Container()
                      ])),
              Container(
                color: widget.backGroundColor_ChildMain ?? widget.backGroundColor_ChildDetails,
                child: ((widget.showingDetails == true) ? widget.childDetails! : Container()),
              ),
            ])));
  }
}

==> xwidgetsbase-10.2.9.tar.gz: lib/XfXWidgets/XfxElencoItem.dart <==
part of xwidgetbase;

class XfxElencoItem extends StatefulWidget {
  XfxElencoItem({
    Key? key,
    this.childMain,
    this.childDetails,
    this.showingDetails = false,
    this.showMainWithDetails = true,
    this.decorationBackGroundContainer,
    this.changeStatoWithTap = true,
    this.onTapItem,
    this.onLongTapItem,
    this.onDoubleTapItem,
    this.margin,
    this.crossAxisAlignment,
    this.backGroundColor_ChildMain,
    this.backGroundColor_ChildDetails,
    this.colorIcon_Collapsed,
    this.colorIcon_Expanded,
    this.colorText_Collapsed,
    this.colorText_Expanded,
    this.showTrailingArrow = true,
    this.icon_Active,
    this.icon_Disabled,
    this.height_Icon,
    this.size_Icon,
    this.width_Icon,
    this.childMain_CrossAxisAlignment,
  }) : super(key: key);

  /// default TRUE
  bool showMainWithDetails;
  Widget? childMain;
  bool showingDetails;
  Widget? childDetails;
  bool changeStatoWithTap;
  bool? showTrailingArrow;
  Color? backGroundColor_ChildMain;
  Color? backGroundColor_ChildDetails;
  Color? colorIcon_Expanded;
  Color? colorIcon_Collapsed;
  Color? colorText_Expanded;
  Color? colorText_Collapsed;
  double? width_Icon;
  double? height_Icon;
  double? size_Icon;
  Decoration? decorationBackGroundContainer;
  EdgeInsetsGeometry? margin;
  CrossAxisAlignment? crossAxisAlignment;
  CrossAxisAlignment? childMain_CrossAxisAlignment;
  IconData? icon_Active;
  IconData? icon_Disabled;
  Function()? onTapItem;
  Function()? onLongTapItem;
  Function()? onDoubleTapItem;
  @override
  _XfxElencoItemState createState() => _XfxElencoItemState();
}

class _XfxElencoItemState extends State<XfxElencoItem> {
  Widget xBuilder_childMain() {
    return widget.childMain ?? Container();
  }

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
        onTap: widget.changeStatoWithTap
            ? widget.onTapItem ??
                () {
                  if (widget.changeStatoWithTap == true) {
                    setState(() => widget.showingDetails = !widget.showingDetails);
                  }
                }
            : null,
        onLongPress: widget.onLongTapItem ?? () {},
        onDoubleTap: widget.onDoubleTapItem ?? () {},
        child: Container(
            decoration: widget.decorationBackGroundContainer ?? BoxDecoration(),
            margin: widget.margin ?? EdgeInsets.only(bottom: 2),
            child: Column(crossAxisAlignment: widget.crossAxisAlignment ?? CrossAxisAlignment.center, children: [
              (widget.showMainWithDetails == false && widget.showingDetails == true)
                  ? Container()
                  : Container(
                      padding: EdgeInsets.all(5),
                      color: widget.backGroundColor_ChildMain,
                      child: Row(crossAxisAlignment: widget.childMain_CrossAxisAlignment ?? CrossAxisAlignment.center, children: [
                        Expanded(child: xBuilder_childMain()),
                        (widget.changeStatoWithTap == true && widget.showTrailingArrow == true)
                            ? Container(
                                // margin: EdgeInsets.only(top: 10),
                                width: widget.width_Icon ?? 40,
                                height: widget.height_Icon ?? 40,
                                child: Icon(
                                  widget.showingDetails ? widget.icon_Active ?? Icons.keyboard_arrow_up_outlined : widget.icon_Disabled ?? widget.icon_Active ?? Icons.keyboard_arrow_down_outlined,
                                  color: (widget.showingDetails == false) ? widget.colorIcon_Collapsed ?? Colors.grey : widget.colorIcon_Expanded ?? Colors.yellow,
                                  size: widget.size_Icon ?? 28,
                                ))
                            : Container()
                      ])),
              Container(
                color: widget.backGroundColor_ChildMain ?? widget.backGroundColor_ChildDetails,
                child: ((widget.showingDetails == true) ? widget.childDetails! : Container()),
              ),
            ])));
  }
}
